==> protr_1.0-1.tar.gz: protr/NEWS.md <==
Version 0.1-0 (2012-11-18)
------------------------------------------------------------------------------

  NEW FEATURES
  
  * initial release
  * initial version of Amino Acid Composition descriptor
  * initial version of Dipeptide Composition descriptor
  * initial version of Tripeptide Composition descriptor
  * initial version of Normalized Moreau-Broto Autocorrelation descriptor
  * initial version of Moran Autocorrelation descriptor
  * initial version of Geary Autocorrelation descriptor
  * initial version of CTD - Composition descriptor
  * initial version of CTD - Transition descriptor
  * initial version of CTD - Distribution descriptor
  * initial version of Conjoint Triad descriptor
  * initial version of Sequence Order Coupling Number descriptor
  * initial version of Quasi-Sequence-Order descriptor
  * initial version of Pseudo Amino Acid Composition descriptor
  * initial version of Amphiphilic Pseudo Amino Acid Composition descriptor
  * initial version of readFASTA()
  * initial version of getUniProt()
  * initial version of protcheck()
  * initial version of protseg()

Version 0.2-0 (2013-12-10)
------------------------------------------------------------------------------

  NEW FEATURES
  
  * second release
  * added Proteochemometric (PCM) Modeling descriptors, parallellized similarity computation derived by protein sequence alignment and Gene Ontology (GO) semantic similarity measures between a list of protein sequences / GO terms / Entrez Gene IDs
  * added misc tools and datasets
  * initial version of Scales-Based Descriptors derived by Principal Components Analysis
  * initial version of Scales-Based Descriptors derived by AA-Properties (AAindex)
  * initial version of Scales-Based Descriptors derived by 20+ classes of 2D and 3D Molecular Descriptors
  * initial version of Scales-Based Descriptors derived by Factor Analysis
  * initial version of Scales-Based Descriptors derived by Multidimensional Scaling
  * initial version of BLOSUM and PAM Matrix-Derived Descriptors
  * initial version of parallelized pairwise similarity calculation with a list of protein sequences
  * initial version of pairwise semantic similarity calculation with a list of GO terms / Entrez Gene IDs
  * initial version of Auto Cross Covariance (ACC) for generating scales-based descriptors of the same length
  * introducing ProtWeb, the web service based on protr: http://cbdd.csu.edu.cn:8080/protrweb/

Version 0.2-1 (2014-01-25)
------------------------------------------------------------------------------

  * Added LICENSE file according to CRAN policies

Version 0.3-0 (2014-06-20)
------------------------------------------------------------------------------

  * Added an example workflow using protr in the vignette

Version 0.4-0 (2014-09-20)
------------------------------------------------------------------------------

  * Added profile-based descriptors derived by PSSM

Version 0.4-1 (2014-10-10)
------------------------------------------------------------------------------

  * Documentation improvements

Version 0.5-0 (2014-12-18)
------------------------------------------------------------------------------

  * Added functions allowing users to specify their own classification of the amino acid
  * Documentation improvements
  * Other minor improvements

Version 0.5-1 (2014-12-22)
------------------------------------------------------------------------------

  * Minor improvements and fixes for documentation

Version 1.0-0 (2015-11-26)
------------------------------------------------------------------------------

  * General improvements for dealing with boundary cases in several functions (thanks for @koefoed's patches)
  * Add citation information

==> protr_1.1-1.tar.gz: protr/NEWS.md <==
Version 0.1-0 (2012-11-18)
------------------------------------------------------------------------------

  NEW FEATURES
  
  * initial release
  * initial version of Amino Acid Composition descriptor
  * initial version of Dipeptide Composition descriptor
  * initial version of Tripeptide Composition descriptor
  * initial version of Normalized Moreau-Broto Autocorrelation descriptor
  * initial version of Moran Autocorrelation descriptor
  * initial version of Geary Autocorrelation descriptor
  * initial version of CTD - Composition descriptor
  * initial version of CTD - Transition descriptor
  * initial version of CTD - Distribution descriptor
  * initial version of Conjoint Triad descriptor
  * initial version of Sequence Order Coupling Number descriptor
  * initial version of Quasi-Sequence-Order descriptor
  * initial version of Pseudo Amino Acid Composition descriptor
  * initial version of Amphiphilic Pseudo Amino Acid Composition descriptor
  * initial version of readFASTA()
  * initial version of getUniProt()
  * initial version of protcheck()
  * initial version of protseg()

Version 0.2-0 (2013-12-10)
------------------------------------------------------------------------------

  NEW FEATURES
  
  * second release
  * added Proteochemometric (PCM) Modeling descriptors, parallellized similarity computation derived by protein sequence alignment and Gene Ontology (GO) semantic similarity measures between a list of protein sequences / GO terms / Entrez Gene IDs
  * added misc tools and datasets
  * initial version of Scales-Based Descriptors derived by Principal Components Analysis
  * initial version of Scales-Based Descriptors derived by AA-Properties (AAindex)
  * initial version of Scales-Based Descriptors derived by 20+ classes of 2D and 3D Molecular Descriptors
  * initial version of Scales-Based Descriptors derived by Factor Analysis
  * initial version of Scales-Based Descriptors derived by Multidimensional Scaling
  * initial version of BLOSUM and PAM Matrix-Derived Descriptors
  * initial version of parallelized pairwise similarity calculation with a list of protein sequences
  * initial version of pairwise semantic similarity calculation with a list of GO terms / Entrez Gene IDs
  * initial version of Auto Cross Covariance (ACC) for generating scales-based descriptors of the same length
  * introducing ProtWeb, the web service based on protr: http://protr.org

Version 0.2-1 (2014-01-25)
------------------------------------------------------------------------------

  * Added LICENSE file according to CRAN policies

Version 0.3-0 (2014-06-20)
------------------------------------------------------------------------------

  * Added an example workflow using protr in the vignette

Version 0.4-0 (2014-09-20)
------------------------------------------------------------------------------

  * Added profile-based descriptors derived by PSSM

Version 0.4-1 (2014-10-10)
------------------------------------------------------------------------------

  * Documentation improvements

Version 0.5-0 (2014-12-18)
------------------------------------------------------------------------------

  * Added functions allowing users to specify their own classification of the amino acid
  * Documentation improvements
  * Other minor improvements

Version 0.5-1 (2014-12-22)
------------------------------------------------------------------------------

  * Minor improvements and fixes for documentation

Version 1.0-1 (2015-11-26)
------------------------------------------------------------------------------

  * General improvements for dealing with boundary cases in several functions (thanks for @koefoed's patches)
  * Add citation information

Version 1.1-0 (2015-12-28)
------------------------------------------------------------------------------

  * Bug fix in `extractCTDD()`

Version 1.1-1 (2015-12-29)
------------------------------------------------------------------------------

  * Fix URLs that cannot be accessed by `curl -I -L`:
    1. Use http://protr.org
    2. Remove all inaccessible URLs
